@@ -1,6 +1,5 @@
 import os
-
-from beauty_print import bp_list
+from typing import List
 
 
 def write_file(file_path, content, mode='w', encoding='utf-8'):
@@ -22,29 +21,38 @@ def write_file(file_path, content, mode='w', encoding='utf-8'):
         fp.write(content)
 
 
-def get_all_file_ab_path(path):
+def get_all_file_ab_path(path, ex: List[str] = None):
     """
     获取路径下所有文件的绝对路径
+    :param ex: 过滤的文件名
     :param path:
-    :return:
+    :return: [文件绝对路径, 文件名]
     """
     files_ab_path = []
     if os.path.isdir(path):
         os.chdir(path)
         all_file = os.listdir()
         for f in all_file:
-            files_ab_path.extend(get_all_file_ab_path(f))
+            files_ab_path.extend(get_all_file_ab_path(f, ex))
 
     else:
+
+        if ex is not None and len(ex) != 0:
+            if os.path.basename(path) in ex:
+                return []
         if os.path.isabs(path):
-            files_ab_path.append(path)
+            files_ab_path.append([path, os.path.basename(path)])
         else:
-            files_ab_path.append(os.path.abspath(path))
+            files_ab_path.append([os.path.abspath(path), os.path.basename(path)])
 
     return files_ab_path
 
 
 if __name__ == '__main__':
     write_file('./testData/write', '1测试1')
-    files_ab_path = get_all_file_ab_path("../ariestools")
-    bp_list(files_ab_path)
+    files_ab_path = get_all_file_ab_path(
+        "../ariestools",
+        ["yaml_util.py", "json_path_util.py"]
+    )
+    for i in files_ab_path:
+        print(i)
