@@ -1,7 +1,7 @@
 import yaml
 
 
-def load_yaml(path):
+def load_yaml(path) -> dict:
     """
     读取一个yaml文件
     :param path: 文件路径
@@ -12,5 +12,11 @@ def load_yaml(path):
 
 
 def write_yaml(data, path):
+    """
+    将对象写yaml
+    :param data:
+    :param path:
+    :return:
+    """
     with open(path, 'w', encoding='utf-8') as f:
         yaml.dump(data, f, allow_unicode=True)
